@@ -21,10 +21,10 @@
 
 #include "filereceiversettings.h"
 
-K_PLUGIN_CLASS_WITH_JSON(Bluetooth, "metadata.json")
+K_PLUGIN_CLASS_WITH_JSON(Bluetooth, "bluetooth.json")
 
-Bluetooth::Bluetooth(QObject *parent, const QVariantList &args)
-    : KQuickAddons::ConfigModule(parent, args)
+Bluetooth::Bluetooth(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KQuickAddons::ConfigModule(parent, data, args)
 {
     KAboutData *about = new KAboutData("kcm_bluetooth", i18n("Bluetooth"), "1.0", QString(), KAboutLicense::GPL);
     about->addAuthor(i18n("Nicolas Fella"), QString(), "nicolas.fella@gmx.de");
@@ -98,7 +98,7 @@ QString Bluetooth::bluetoothStatusAtLogin() const
     return globalGroup.readEntry("launchState", "remember");
 }
 
-void Bluetooth::setBluetoothStatusAtLogin(const QString newStatus)
+void Bluetooth::setBluetoothStatusAtLogin(const QString &newStatus)
 {
     auto config = KSharedConfig::openConfig(QStringLiteral("bluedevilglobalrc"));
     KConfigGroup globalGroup = config->group("Global");
