@@ -15,7 +15,7 @@ class Bluetooth : public KQuickAddons::ConfigModule
     Q_OBJECT
 
 public:
-    Bluetooth(QObject *parent, const QVariantList &args);
+    Bluetooth(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
 
     Q_INVOKABLE void runWizard();
     Q_INVOKABLE void runSendFile(const QString &ubi);
@@ -26,7 +26,7 @@ public:
     Q_PROPERTY(QString bluetoothStatusAtLogin READ bluetoothStatusAtLogin WRITE setBluetoothStatusAtLogin NOTIFY bluetoothStatusAtLoginChanged)
 
     QString bluetoothStatusAtLogin() const;
-    void setBluetoothStatusAtLogin(QString newStatus);
+    void setBluetoothStatusAtLogin(const QString &newStatus);
 
 Q_SIGNALS:
     void networkAvailable(const QString &service, bool available);
