@@ -40,18 +40,22 @@ public:
     BluezQt::DevicePtr device() const;
     void setDevice(BluezQt::DevicePtr device);
 
+    QString errorMessage() const;
+    void setErrorMessage(const QString &message);
+
     void startTransfer(const QDBusObjectPath &session);
 
 private Q_SLOTS:
     void initJobResult(BluezQt::InitManagerJob *job);
 
 private:
-    QString m_deviceUrl;
+    const QString m_deviceUrl;
     QStringList m_files;
+    QString m_errorMessage;
 
-    BluezQt::Manager *m_manager;
+    BluezQt::Manager *m_manager = nullptr;
     BluezQt::DevicePtr m_device;
-    SendFilesJob *m_job;
+    SendFilesJob *m_job = nullptr;
 };
 
 #endif // SENDFILEWIZARD_H
